@@ -6,7 +6,7 @@ import logging
 import aiohttp
 
 from typing import Any
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from .const import CONNECT_ERRORS
 
 from .model import Py2NDeviceData, Py2NConnectionData
@@ -67,12 +67,13 @@ class Py2NDevice:
             self._info = await get_info(self.aiohttp_session, self.options)
             self._status = await get_status(self.aiohttp_session, self.options)
 
-            self.data = Py2NDeviceData(
+            self._data = Py2NDeviceData(
                 name=self._info["deviceName"],
                 model=self._info["variant"],
                 serial=self._info["serialNumber"],
-                firmware=self._info["swVersion"],
-                uptime=datetime.now() - timedelta(seconds=self._status["upTime"])
+                firmware=f"{self._info['swVersion']}-{self._info['buildType']}",
+                hardware=self._info["hwVersion"]
+                uptime=datetime.now(timezone.utc) - timedelta(seconds=self._status["upTime"])
             )
         except InvalidAuthError as err:
             self._last_error = err
@@ -83,7 +84,7 @@ class Py2NDevice:
             _LOGGER.debug("host %s: error: %r", ip, self._last_error)
             raise DeviceConnectionError(err) from err
 
-        return self.data
+        return self._data
 
     @property
     def ip_address(self) -> str:
@@ -96,4 +97,4 @@ class Py2NDevice:
         if not self.initialized:
             raise NotInitialized
 
-        return self.data
\ No newline at end of file
+        return self._data
\ No newline at end of file
